==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/DhcpOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.DhcpOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * DhcpOptions contains an array of DNS servers available to VMs deployed in the virtual network. Standard DHCP option for a subnet overrides VNET DHCP options.
 * @property dnsServers The list of DNS servers IP addresses.
 */
public data class DhcpOptionsArgs(
    public val dnsServers: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.DhcpOptionsArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.DhcpOptionsArgs =
        com.pulumi.azurenative.network.inputs.DhcpOptionsArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DhcpOptionsArgs].
 */
@PulumiTagMarker
public class DhcpOptionsArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    /**
     * @param value The list of DNS servers IP addresses.
     */
    @JvmName("ugjhnqvtxlksimok")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("qrwremptmucirbcw")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values The list of DNS servers IP addresses.
     */
    @JvmName("ohymawglnxrkgmpg")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value The list of DNS servers IP addresses.
     */
    @JvmName("lbbghninorsdfxjq")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values The list of DNS servers IP addresses.
     */
    @JvmName("clytvewkjlmgmpxc")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    internal fun build(): DhcpOptionsArgs = DhcpOptionsArgs(
        dnsServers = dnsServers,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/DhcpOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.DhcpOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * DhcpOptions contains an array of DNS servers available to VMs deployed in the virtual network. Standard DHCP option for a subnet overrides VNET DHCP options.
 * @property dnsServers The list of DNS servers IP addresses.
 */
public data class DhcpOptionsArgs(
    public val dnsServers: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.DhcpOptionsArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.DhcpOptionsArgs =
        com.pulumi.azurenative.network.inputs.DhcpOptionsArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DhcpOptionsArgs].
 */
@PulumiTagMarker
public class DhcpOptionsArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    /**
     * @param value The list of DNS servers IP addresses.
     */
    @JvmName("qjsclscwnygxmrtd")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("bhmrtkrtwmwtpghr")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values The list of DNS servers IP addresses.
     */
    @JvmName("wlhoimkuxipauwtg")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value The list of DNS servers IP addresses.
     */
    @JvmName("pubrkbiheejxcmkw")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values The list of DNS servers IP addresses.
     */
    @JvmName("vobyxnkybmfpbfbu")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    internal fun build(): DhcpOptionsArgs = DhcpOptionsArgs(
        dnsServers = dnsServers,
    )
}
